function M = initialize()
% [D,F,M] = MERGED.ODE.INITIALIZE() generates the data for master ode model
% D - the data of decoy model, generated by Decoy.ODE.initialize(), to be
% used in Merged.ODE.ode
% F - the data of FNR model, generated by FNR.ODE.initialize(), to be used
% in Merged.ODE.ode
% M - the data of master model, to be used in Tools.steadystate
% the structure of M looks like this:
% M
%   .info
%       .model                              - 'master'
%   .Decoy                                  - Decoy struct
%   .FNR                                    - FNR struct
%   .amounts(id)                            - initial concentrations
%   .oxygen                                 - oxygen concentrations

S.info.model            = 'Merged';
S.info.species          = 12;
S.info.reactions        = 5;
S.info.rules            = 3;
S.info.volume           = 0.6E-15;    % the volume of E.ocli in L
S.info.NA               = 6.023E23;       % the Avogadro's constant
S.info.copyNumber       = 17.5;

%% Species
S.species.toName = containers.Map('KeyType','uint32','ValueType','char');
S.species.toID = containers.Map('KeyType','char','ValueType','uint32');

S.species.FNRmRNA       = 1;
S.species.InactiveFNR   = 2;
S.species.ActiveFNR     = 3;
S.species.T0            = 4;
S.species.T             = 3;
S.species.N             = 5;
S.species.TN            = 6;
S.species.N0            = 7;
S.species.P             = 8;
S.species.TP            = 9;
S.species.PT            = 10;
S.species.TPT           = 11;
S.species.P0            = 12;

%% Reactions
S.stoichiometry = sparse(zeros(S.info.species,S.info.reactions));

S.reaction.TpN_TN       = 1;
S.reaction.TpP_TP       = 2;
S.reaction.PpT_PT       = 3;
S.reaction.TPpT_TPT     = 4;
S.reaction.PTpT_TPT     = 5;

%% Rules
S.rule.T0               = 1;
S.rule.N0               = 2;
S.rule.P0               = 3;

%% Paramters
S.parameters.toID = containers.Map('KeyType','char','ValueType','uint32');

S.parameters.a1         = 1;
S.parameters.a1max      = 2;
S.parameters.a21        = 3;
S.parameters.a22        = 4;
S.parameters.b22        = 5;
S.parameters.b1a        = 6;
S.parameters.b1n        = 7;
S.parameters.b21a       = 8;
S.parameters.b21n       = 9;
S.parameters.b31a       = 10;
S.parameters.b31n       = 11;
S.parameters.g13        = 12;
S.parameters.x4         = 13;
S.parameters.x5         = 14;
S.parameters.x3c        = 15;
S.parameters.oxygen     = 16;
S.parameters.Knplus     = 17;
S.parameters.Knmin      = 18;
S.parameters.Ktpplus    = 19;
S.parameters.Ktpmin     = 20;
S.parameters.Kptplus    = 21;
S.parameters.Kptmin     = 22;
S.parameters.Ktp_tptplus = 23;
S.parameters.Ktp_tptmin = 24;
S.parameters.Kpt_tptplus = 25;
S.parameters.Kpt_tptmin = 26;
S.parameters.copyNumber = 28;
S.parameters.volume     = 29;
S.parameters.expression_tpt = 30;
S.parameters.expression_pt = 31;

M = Merged.ODE.setup(S);

end